import { Plugin } from 'rollup';
export interface ReplaceImportsOptions {
    /**
     * Instructs the plugin the type of variable declaration to use
     * @default const
     **/
    varType?: 'const' | 'let' | 'var';
    /**
     * Instructs the plugin what javascript var or namespace to place
     * as the right side of the declaration statement. For example,
     * { '@material-ui/core': 'window.MaterialUI' }
     * @default {}
     * */
    replacementLookup: Record<string, string>;
    /**
     * Same as replacementLookup but with regular expressions. The key should be a string that will
     * be passed to RegExp constructor to check against the `from` part of the import statement. The
     * value should be a function that's called when there's a match and should return the
     * global/namespace where to initialize the import from.
     * @default {}
     * */
    replacementRegExps: Record<string, (match: RegExpExecArray) => string>;
}
export default function replaceImports(options: ReplaceImportsOptions): Plugin;
