'use strict';

var toRegExp = function (str) {
  try {
    return new RegExp(str);
  } catch (_a) {
    return null;
  }
};
var AllAsXRegExp = /\*\s+as\s+([\w$]*)/g;
function replaceImports(options) {
  var _a = options.varType,
    varType = _a === void 0 ? 'const' : _a,
    _b = options.replacementLookup,
    replacementLookup = _b === void 0 ? {} : _b,
    _c = options.replacementRegExps,
    replacementRegExps = _c === void 0 ? {} : _c;
  var regExpsKeys = Object.keys(replacementRegExps);
  var regExps = regExpsKeys.map(toRegExp).filter(Boolean);
  return {
    name: 'rollup-plugin-replace-imports-with-vars',
    renderChunk: function (code) {
      return code.replace(
        /import\s+([\w$*\s{},]*)\s+from\s+('.*?'|".*?")/g,
        function (match, imports, fromUri, offset, string) {
          var fromName = fromUri.replace(/['"]/g, '');
          var source = replacementLookup[fromName];
          var regExp;
          if (!source) {
            var index = regExps.findIndex(function (regExp) {
              return regExp.test(fromName);
            });
            regExp = regExps[index];
            if (regExp === null || regExp === void 0 ? void 0 : regExp.test(fromName)) {
              source = replacementRegExps[regExpsKeys[index]](regExp.exec(fromName));
            }
          }
          if (source) {
            var trimmedImports = imports.trim();
            var pieces_1 = [];
            var allAsX = trimmedImports.match(AllAsXRegExp);
            var namedExports = trimmedImports.match(/{.*?}/g);
            var defaultExports = trimmedImports.replace(
              /({.*?})|(?:\*\s+as\s+([\w$]*))|[,\s]/g,
              ''
            );
            if (allAsX) {
              allAsX.forEach(function (chunk) {
                return pieces_1.push(varType + ' ' + AllAsXRegExp.exec(chunk)[1] + ' = ' + source);
              });
            }
            if (namedExports) {
              namedExports.forEach(function (chunk) {
                return pieces_1.push(
                  varType +
                    ' ' +
                    chunk.replace(/([a-zA-Z0-9$_]+) as ([a-zA-Z0-9$_]+)/g, '$1: $2') +
                    ' = ' +
                    source
                );
              });
            }
            if (defaultExports) {
              pieces_1.push(
                varType +
                  ' ' +
                  defaultExports +
                  ' = ' +
                  source +
                  ' && Object.prototype.hasOwnProperty.call(' +
                  source +
                  ", 'default') ? " +
                  source +
                  "['default'] : " +
                  source
              );
            }
            if (pieces_1.length) {
              return pieces_1.join(';\n');
            } else {
              return string;
            }
          } /*else if (specificNamedExports[fromName]) {
                  const data = specificNamedExports[fromName];
                  const trimmedImports = imports.trim();
                  const namedExports = trimmedImports.match(/{(.+)}/);
                  if (namedExports) {
                    const pieces = [];
                    const matches = [];
                    const remaining = [];
                    namedExports[1].trim().split(',').forEach((namedExport) => {
                      if (data.targets.includes(namedExport)) {
                        matches.push(namedExport.replace(/([a-zA-Z0-9$_]+)\s+as\s+([a-zA-Z0-9$_]+)/, '$1: $2'))
                      } else {
                        remaining.push(namedExport);
                      }
                    });
                    if (matches.length) {
                      pieces.push(`${varType} { ${matches.join(',')} } = ${data.source}`)
                      if (remaining.length) {
                        pieces.push(`import { ${remaining.join(',')} } from ${fromUri}`)
                      }
                      return pieces.join(';\n');
                    } else {
                      return string;
                    }
                  } else {
                    return string
                  }
                }*/ else {
            return match;
          }
        }
      );
    },
  };
}

module.exports = replaceImports;
